@@ -21,5 +21,5 @@ def str2bool(v) -> bool:
     raise ValueError(f"{v} is not convertible to boolean!")
 
 
-def emeki():
-    print("Hoi")
+def emeki_main():
+    print("Hoi! This is my personal python library.")
